@@ -42,23 +42,28 @@ MessageDescription::ConstPtr DescriptionProvider::getMessageDescription( const s
   return getMessageDescriptionImpl( type );
 }
 
-MessageDescription::ConstPtr DescriptionProvider::getMessageDescription( const BabelFishMessage &msg )
+MessageDescription::ConstPtr DescriptionProvider::getMessageDescription( const IBabelFishMessage &msg )
 {
-  const std::string &type = msg.dataType();
-  const std::string &md5 = msg.md5Sum();
+  return getMessageDescription( msg.dataType(), msg.md5Sum(), msg.definition());
+}
 
+MessageDescription::ConstPtr
+DescriptionProvider::getMessageDescription( const std::string &type, const std::string &md5,
+                                            const std::string &definition )
+{
   // Check cache
   auto it = message_descriptions_.find( type );
   if ( it != message_descriptions_.end())
   {
     if ( it->second->md5 != md5 )
     {
-      throw BabelFishException( "Message found but MD5 sum differed!" );
+      throw BabelFishException( "Message '" + type +"' found but MD5 sum differed!\n" +
+                                md5 + " (provided) vs " + it->second->md5 + " (cached)." );
     }
     return it->second;
   }
 
-  return getMessageDescriptionImpl( msg );
+  return getMessageDescriptionImpl( type, definition );
 }
 
 ServiceDescription::ConstPtr DescriptionProvider::getServiceDescription( const std::string &type )
@@ -198,7 +203,7 @@ MessageDescription::ConstPtr DescriptionProvider::getMessageDescriptionImpl( con
   return registerMessage( spec, computeFullText( spec ));
 }
 
-MessageDescription::ConstPtr DescriptionProvider::getMessageDescriptionImpl( const BabelFishMessage &msg )
+MessageDescription::ConstPtr DescriptionProvider::getMessageDescriptionImpl( const IBabelFishMessage &msg )
 {
   return getMessageDescriptionImpl( msg.dataType(), msg.definition());
 }
@@ -212,10 +217,25 @@ MessageTemplate::Ptr DescriptionProvider::createTemplate( const MessageSpec &spe
   for ( auto &constant : spec.constants )
   {
     Message::Ptr value;
-    if ( constant.type == "bool" || constant.type == "uint8" || constant.type == "char" )
+    if ( constant.type == "uint8" || constant.type == "char" )
     {
       value = std::make_shared<ValueMessage<uint8_t>>( static_cast<uint8_t>(std::stoi( constant.val )));
     }
+    else if ( constant.type == "bool" )
+    {
+      if ( constant.val == "True" )
+      {
+        value = std::make_shared<ValueMessage<bool>>( true );
+      }
+      else if ( constant.val == "False" )
+      {
+        value = std::make_shared<ValueMessage<bool>>( false );
+      }
+      else
+      {
+        value = std::make_shared<ValueMessage<bool>>( static_cast<bool>(std::stoi( constant.val )));
+      }
+    }
     else if ( constant.type == "int8" || constant.type == "byte" )
     {
       value = std::make_shared<ValueMessage<int8_t>>( static_cast<int8_t>(std::stoi( constant.val )));
